pyhsm.aead_cmd.YHSM_AEAD_Cmd

Package pyhsm :: Module aead_cmd :: Class YHSM_AEAD_Cmd |
[frames] | no frames]

# Class YHSM_AEAD_Cmd

    cmd.YHSM_Cmd --+
                   |
                  YHSM_AEAD_Cmd

Known Subclasses:
  - YHSM_Cmd_AEAD_Buffer_Generate
  - , YHSM_Cmd_AEAD_Generate
  - , YHSM_Cmd_AEAD_Random_Generate
  - , validate_cmd.YHSM_Cmd_AEAD_Validate_OTP

Class for common non-trivial parse_result for commands returning a YSM_AEAD_GENERATE_RESP.

Instance Methods
__repr__(self) |
parse_result(self, data) Returns a YHSM_GeneratedAEAD instance, or throws pyhsm.exception.YHSM_CommandFailed. |
Inherited from `cmd.YHSM_Cmd`: `__init__`, `execute`

Class Variables
| key_handle = `0`
| nonce = ``'````'``
| response = `None`
| status = `0`
Inherited from `cmd.YHSM_Cmd`: `executed`, `response_status`

Method Details

### parse_result(self, data) |
Returns a YHSM_GeneratedAEAD instance, or throws pyhsm.exception.YHSM_CommandFailed. Overrides: cmd.YHSM_Cmd.parse_result